# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.swagger_client
from curia.api.swagger_client.models.model_job_event import ModelJobEvent  # noqa: E501
from curia.api.swagger_client.rest import ApiException


class TestModelJobEvent(unittest.TestCase):
    """ModelJobEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testModelJobEvent(self):
        """Test ModelJobEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.model_job_event.ModelJobEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
